Index: device/gamepad/gamepad_service.h |
diff --git a/device/gamepad/gamepad_service.h b/device/gamepad/gamepad_service.h |
index c5e4aafa0309b46ae02fa2d2ecf6e5d9ccd4b4ad..530178414927dbe39b83f478894d5effc15402b3 100644 |
--- a/device/gamepad/gamepad_service.h |
+++ b/device/gamepad/gamepad_service.h |
@@ -67,10 +67,8 @@ class DEVICE_GAMEPAD_EXPORT GamepadService |
// while a consumer is active. |
void RegisterForUserGesture(const base::Closure& closure); |
- // Returns the shared memory handle of the gamepad data duplicated into the |
- // given process. |
- base::SharedMemoryHandle GetSharedMemoryHandleForProcess( |
- base::ProcessHandle handle); |
+ // Returns a duplicate of the shared memory handle of the gamepad data. |
+ base::SharedMemoryHandle DuplicateSharedMemoryHandle(); |
// Returns a new mojo::ScopedSharedBuffer handle of the gamepad data. |
mojo::ScopedSharedBufferHandle GetSharedBufferHandle(); |